<?php
// $Id: quickbar.admin.inc,v 1.1.2.1 2011/02/16 06:04:52 redndahead Exp $

/**
 * @file
 * Handles quickbar administration
 *
 * Assign roles a toolbar.
 */

/**
 * Page to administer quickbar
 *
 * Sets which role uses which menu for it's quickbar.
 *
 * @return
 *  A form setting quicbar menus per role.
 */
function quickbar_form(&$form_state) {
  
  $form['settings_header'] = array(
    '#value' => '<h2>' . t('Settings') . '</h2>',
  );
  
  $form['settings_icon_bypass'] = array(
    '#type' => 'checkbox',
    '#title' => 'Do not load the icons css.  This will make it easier for other themes to provide different icons like Rubik.',
    '#default_value' => variable_get('quickbar_icon_bypass', 0),
  );
  
  $form['menus_header'] = array(
    '#value' => '<h2>' . t('Assign Menus To Roles') . '</h2>',
  );
  
  $form['intro'] = array(
    '#value' => '<p>' . t('Choose which menu should be used for each role. If a user has multiple roles they will get the menu of the higher role which has an assigned menu.') . '</p>',
  );
  
  $menus = menu_get_menus();
  
  $roles = user_roles();
  $weighted_roles = unserialize(variable_get('quickbar_role_weights', ''));
  foreach ($roles as $rid => $name) {
    if (empty($weighted_roles[$rid])) {
      $weighted_roles[$rid] = 0;
    }
  }
  
  array_unshift($menus, 'None');
  foreach ($weighted_roles as $rid => $weight) {
    $form['toolbar_title_' . $rid] = array(
      '#type' => 'markup',
      '#value' => $roles[$rid],
    );
    
    $form['toolbar_weight_' . $rid] = array(
      '#type' => 'weight',
      '#default_value' => $weight,
      // drag group
      '#attributes' => array('class' => 'quickbar-role-order-weight')
    );
    
    $form['toolbar_' . $rid] = array(
      '#type' => 'select',
      '#default_value' => variable_get('quickbar_' . $rid, 0), 
      '#options' => $menus,
    );
  }
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  return $form;
}

/**
 * Submit handler for quickbar_form()
 *
 * @see quickbar_form()
 * @ingroup forms
 */
function quickbar_form_submit(&$form, &$form_state) {
  variable_set('quickbar_icon_bypass', $form_state['values']['settings_icon_bypass']);
  
  $roles = user_roles();
  
  $weights = array();
  foreach ($roles as $rid => $name) {
    variable_set('quickbar_' . $rid, $form_state['values']['toolbar_' . $rid]);
    $weights[$rid] = $form_state['values']['toolbar_weight_' . $rid];
  }
  
  variable_set('quickbar_role_weights', serialize($weights));
  
  drupal_set_message('The toolbars have been saved.');
  
}

/**
 * Theme handler for quickbar_form()
 *
 * @see theme_quickbar_form()
 * @ingroup themable
 */
function theme_quickbar_form($form) {
  
  $output = drupal_render($form['settings_header']);
  $output .= drupal_render($form['settings_icon_bypass']);
  $output .= drupal_render($form['menus_header']);
  $output .= drupal_render($form['intro']);
  
  // Get the weighted list of roles and add roles that haven't been weighted yet
  $roles = unserialize(variable_get('quickbar_role_weights', ''));
  foreach (user_roles() as $rid => $name) {
    if (empty($roles[$rid])) {
      $roles[$rid] = 0;
    }
  }
  
  // Sort the roles.
  asort($roles);
  
  // Build the table rows.
  $rows = array();
  foreach ($roles as $rid => $name) {
    $rows[] = array(
      'data' => array(
        drupal_render($form['toolbar_title_' . $rid]),
        drupal_render($form['toolbar_' . $rid]),
        drupal_render($form['toolbar_weight_' . $rid]),
      ),
      'class' => 'draggable',
    );
  }

  // Build our draggable table
  $header = array(t('Role'), array('data' => t('Assigned Menu'), 'colspan' => 2));
  $output .= theme('table', $header, $rows, array('id' => 'quickbar-role-order'));
  $output .= drupal_render($form);

  drupal_add_tabledrag('quickbar-role-order', 'order', 'sibling', 'quickbar-role-order-weight');

  return $output;
}
